Documentation
¶
Index ¶
- func Debug(v ...interface{})
- func Debugf(format string, v ...interface{})
- func Debugln(v ...interface{})
- func Error(v ...interface{})
- func Errorf(format string, v ...interface{})
- func Errorln(v ...interface{})
- func Flags() int
- func Info(v ...interface{})
- func Infof(format string, v ...interface{})
- func Infoln(v ...interface{})
- func SetFlags(flags int)
- func SetOutput(w io.Writer)
- func SetSeverity(level severity.Level)
- func Severity() severity.Level
- type Logger
- func (l *Logger) Debug(v ...interface{})
- func (l *Logger) Debugf(format string, v ...interface{})
- func (l *Logger) Debugln(v ...interface{})
- func (l *Logger) Error(v ...interface{})
- func (l *Logger) Errorf(format string, v ...interface{})
- func (l *Logger) Errorln(v ...interface{})
- func (l *Logger) Flags() int
- func (l *Logger) Info(v ...interface{})
- func (l *Logger) Infof(format string, v ...interface{})
- func (l *Logger) Infoln(v ...interface{})
- func (l *Logger) SetFlags(flags int)
- func (l *Logger) SetOutput(w io.Writer)
- func (l *Logger) SetSeverity(level severity.Level)
- func (l *Logger) Severity() severity.Level
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Debug ¶
func Debug(v ...interface{})
Debug logs with `debug` severity to the default logger. Arguments are handled in the same manner as fmt.Print, but a new line is appended to the end if one not specified.
func Debugf ¶
func Debugf(format string, v ...interface{})
Debugf logs with `debug` severity to the default logger. Arguments are handled in the same manner as fmt.Printf, but a new line is appended to the end if one not specified.
func Debugln ¶
func Debugln(v ...interface{})
Debugln logs with `debug` severity to the default logger. Arguments are handled in the same manner as fmt.Println.
func Errorf ¶
func Errorf(format string, v ...interface{})
Errorf is like Debugf, but logs at an `error` severity.
func Errorln ¶
func Errorln(v ...interface{})
Errorln is like Debugln, but logs with `error` severity.
func Infof ¶
func Infof(format string, v ...interface{})
Infof is like Debugf, but logs with `info` severity.
func SetSeverity ¶
SetSeverity sets the minimum severity level the default logger logs at.
Types ¶
type Logger ¶
Logger - Severity based log writer.
func (*Logger) Debug ¶
func (l *Logger) Debug(v ...interface{})
Debug logs with `debug` severity. Arguments are handled in the same manner as fmt.Print, but a new line is appended to the end if one not specified.
func (*Logger) Debugf ¶
Debugf logs with `debug` severity. Arguments are handled in the same manner as fmt.Printf, but a new line is appended to the end if one not specified.
func (*Logger) Debugln ¶
func (l *Logger) Debugln(v ...interface{})
Debugln logs with `debug` severity. Arguments are handled in the same manner as fmt.Println.
func (*Logger) Error ¶
func (l *Logger) Error(v ...interface{})
Error is like Debug, but logs with `error` severity.
func (*Logger) Errorln ¶
func (l *Logger) Errorln(v ...interface{})
Errorln is like Debugln, but logs with `error` severity.
func (*Logger) Info ¶
func (l *Logger) Info(v ...interface{})
Info is like Debug, but logs with `info` severity.
func (*Logger) Infoln ¶
func (l *Logger) Infoln(v ...interface{})
Infoln is like Debugln, but logs with `info` severity.
func (*Logger) SetSeverity ¶
SetSeverity sets minimum severity level logged.